@@ -8,7 +8,7 @@ import pandas as pd
 import matplotlib.lines as lines
 
 
-def fis_dark_theme():
+def dark_theme():
     darked = '#303030'
     light_white = '#FFFEF1'
     sns.set(rc={
@@ -42,7 +42,7 @@ def fis_dark_theme():
     rcParams['axes.prop_cycle'] = cycler(color=dark_theme_colors)
     rcParams['image.cmap'] = 'inferno'
 
-def fis_light_theme():
+def light_theme():
     dark_blue = "#152238"
     sns.set(rc={
         'text.color':dark_blue,
@@ -65,14 +65,13 @@ def fis_light_theme():
     rcParams['grid.color'] = light_white
     rcParams['image.cmap'] = 'inferno'
 
-def fis_business_theme():
+def business_theme():
     dark_blue =  "#152238"
     cadet_blue = "#364D6E"
     white =      "#FFFFFF"
     light_blue = "#DAE3F3"
     silver =     "#D6D7D9"
-    business_colors = ["#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9",
-                    "#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9"]
+    business_colors = ["#97ACCF","#D6D7D9","#A7A8AA","#B6E1F6","#DAE3F3","#2f6997","#7A7B7D","#00b7c7","#505153","#8bd3c7","#3E4756","#0d88e6"]
     sns.set(rc={
         'text.color':dark_blue,
         'axes.labelcolor':dark_blue,
@@ -99,7 +98,7 @@ def fis_business_theme():
     rcParams['grid.color'] = white
     rcParams['image.cmap'] = 'Blues'
 
-def fis_get_colors(theme):
+def get_colors(theme):
     if theme == 'light':
         dark_theme_colors = ["#fd7f6f", "#7eb0d5", "#b2e061", "#bd7ebe", "#ffb55a", "#ffee65", "#beb9db", "#fdcce5", "#8bd3c7"]
         dark_theme_colors + ["#e60049", "#0bb4ff", "#50e991", "#e6d800", "#9b19f5", "#ffa300", "#dc0ab4", "#b3d4ff", "#00bfa0"]
@@ -115,7 +114,7 @@ def fis_get_colors(theme):
         dark_theme_colors + ["#ea5545", "#f46a9b", "#ef9b20", "#edbf33", "#ede15b", "#bdcf32", "#87bc45", "#27aeef", "#b33dc6"]
         return dark_theme_colors
     elif theme == 'business':
-        business_colors = ["#D6D7D9","#97ACCF","#A7A8AA","#B6E1F6","#DAE3F3","#2f6997","#7A7B7D","#00b7c7","#505153","#8bd3c7","#3E4756","#0d88e6"]        
+        business_colors = ["#97ACCF","#D6D7D9","#A7A8AA","#B6E1F6","#DAE3F3","#2f6997","#7A7B7D","#00b7c7","#505153","#8bd3c7","#3E4756","#0d88e6"]        
         return business_colors
     else:
         return None
